==> rucy-0.4.0.tar.gz: rucy-0.4.0/test/test_loader.rb <==
#!/usr/local/bin/ruby
# $Id: test_loader.rb,v 1.5 2004/12/18 03:22:04 toki Exp $

require 'rubyunit'
require 'rucy/loader'

module TestRucy
  class TestSimpleLoader < RUNIT::TestCase
    def setup
      # target
      @loader = Rucy::SimpleLoader.new
    end

    def teardown
      File.delete('load_test.rb') if (File.exist? 'load_test.rb')
    end

    def test_load
      File.open('load_test.rb', 'w') {|output|
	output.print "class Foo\n"
	output.print "end\n"
	output.print "module Bar\n"
	output.print "end\n"
      }
      @loader.load('load_test.rb')
      assert_equal(%w[ Foo Bar ].sort, @loader.constants.sort)
      assert_instance_of(Class, @loader.const_get('Foo'))
      assert_instance_of(Module, @loader.const_get('Bar'))
      assert((@loader.const_defined? 'Foo'))
      assert(! (@loader.const_defined? 'Baz'))
    end
  end

  class TestModuleFolder < RUNIT::TestCase
    def setup
      @load_path = 'load_path_for_test'
      Dir.mkdir(@load_path)

      # target
      @mod_folder = Rucy::ModuleFolder.new(@load_path)
    end

    def teardown
      Dir.foreach(@load_path) do |name|
	next if (name == '.' || name == '..')
	path = File.join(@load_path, name)
	case (File.ftype(path))
	when 'directory'
	  Dir.rmdir(path)
	else
	  File.unlink(path)
	end
      end
      Dir.rmdir(@load_path)
    end

    def touch(path)
      File.open(path, 'w') {|output|
	# nothing to do.
      }
      nil
    end
    private :touch

    def test_scan
      touch(File.join(@load_path, 'foo'))
      touch(File.join(@load_path, 'bar.rb'))
      Dir.mkdir(File.join(@load_path, 'baz'))
      Dir.mkdir(File.join(@load_path, 'baz.rb'))

      done = false
      @mod_folder.scan do |path|
	assert_equal(File.join(@load_path, 'bar.rb'), path)
	done = true
      end
      assert(done)
    end
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/test/test_loader.rb <==
#!/usr/local/bin/ruby
# $Id: test_loader.rb,v 1.6 2005/02/05 04:34:19 toki Exp $

require 'rubyunit'
require 'rucy/loader'

module TestRucy
  class TestSimpleLoader < RUNIT::TestCase
    def setup
      # target
      @loader = Rucy::SimpleLoader.new
    end

    def teardown
      File.delete('load_test.rb') if (File.exist? 'load_test.rb')
    end

    def test_load
      File.open('load_test.rb', 'w') {|output|
	output.print "class Foo\n"
	output.print "end\n"
	output.print "module Bar\n"
	output.print "end\n"
      }
      @loader.load('load_test.rb')
      assert_equal(%w[ Foo Bar ].sort, @loader.constants.sort)
      assert_instance_of(Class, @loader.const_get('Foo'))
      assert_instance_of(Module, @loader.const_get('Bar'))
      assert((@loader.const_defined? 'Foo'))
      assert(! (@loader.const_defined? 'Baz'))
    end
  end

  class TestModuleFolder < RUNIT::TestCase
    def setup
      @load_path = 'load_path_for_test'
      Dir.mkdir(@load_path)

      # target
      @mod_folder = Rucy::ModuleFolder.new(@load_path)
    end

    def teardown
      Dir.foreach(@load_path) do |name|
	next if (name == '.' || name == '..')
	path = File.join(@load_path, name)
	case (File.ftype(path))
	when 'directory'
	  Dir.rmdir(path)
	else
	  File.unlink(path)
	end
      end
      Dir.rmdir(@load_path)
    end

    def touch(path)
      File.open(path, 'w') {|output|
	# nothing to do.
      }
      nil
    end
    private :touch

    def test_scan
      touch(File.join(@load_path, 'foo'))         # skip
      touch(File.join(@load_path, 'bar.rb'))      # scanned
      touch(File.join(@load_path, '_nothing.rb')) # skip
      Dir.mkdir(File.join(@load_path, 'baz'))     # skip
      Dir.mkdir(File.join(@load_path, 'baz.rb'))  # skip

      done = false
      @mod_folder.scan do |path|
	assert_equal(File.join(@load_path, 'bar.rb'), path)
	done = true
      end
      assert(done)
    end
  end
end
